<?php

namespace App\Http\Helpers;

use GuzzleHttp\Client;
use App\Http\Helpers\Json;
use App\Http\Helpers\APISettings;
use Illuminate\Support\Facades\Config;
use GuzzleHttp\Exception\ClientException;

class RestClient extends Client {

    private $authToken;

    public function __construct(array $config = []) {
        if (!isset($config['timeout'])) {
            $config['timeout'] = '10.0';
        }
        if (!isset($config['base_uri'])) {
            $config['base_uri'] = APISettings::BASE_URL;
        }

        parent::__construct($config);
    }

    public function getRequest($uri, array $options = []) {
        return $this->makeRequest('GET', $uri, $options);
    }

    public function postRequest($uri, $body = [], array $options = []) {
        if (!isset($options['form_params'])) {
            $options['form_params'] = $body;
        }
        return $this->makeRequest('POST', $uri, $options);
    }

    private function makeRequest($method, $uri, array $options = []) {
        if (!isset($options['headers']['authorization'])) {
            $options['headers']['authorization'] = 'Bearer ' . $this->authToken;
        }
        try {
            return $this->request($method, $uri, $options);
        } catch (\GuzzleHttp\Exception\ClientException $e) {
            return $e->getResponse();
        }
    }

    public function getAuthToken() {
        $options['headers']['Content-Type'] = APISettings::CONTENT_TYPE_URL_ENCODED;
        $options['headers']['accept'] = APISettings::ACCEPT_JSON;
        $body = ['grant_type' => APISettings::GRANT_TYPE, 'username' => APISettings::USERNAME, 'password' => APISettings::PASSWORD];
        $prepare = $this->postRequest(APISettings::BASE_URL . APISettings::TOKEN_URI, $body, $options);
        $results = $prepare->getBody()->getContents();
        if (Json::isValid($results)) {
            if (isset(json_decode($results)->access_token) && json_decode($results)->access_token != '') {
                $this->authToken = json_decode($results)->access_token;
            }
        }
    }

    public function sendSms($phone, $text) {
        $password = Config::get('constants.sms-api-password');
        $uri = "http://pk.eocean.us/APIManagement/API/RequestAPI?user=AMANTECH&pwd=" . $password . "&sender=AMANTECH%20CS&reciever=" . $phone . "&msg-data=" . urlencode($text) . "&response=string";
        return $this->request('GET', $uri);
    }

}
