<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use App\Http\Requests;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use App\Http\Controllers\Controller;
use App\Http\Helpers\StringHelper;
use App\Http\Helpers\SettingHelper;
use App\Http\Helpers\MediaHelper;
use Intervention\Image\Facades\Image;
use App\Models\Category;
use App\Models\Post;
use App\Models\Brand;
use App\Models\Attribute;
use App\Models\PostAttribute;
use App\Models\Media;

class PostController extends Controller {

    public function index($type = "page") {
        $typeSetting = SettingHelper::getSetting($type);
        if (!$typeSetting) {
            return redirect($this->adminURI . '404');
        }
        $pageTitle = SettingHelper::getPageTitleByType($typeSetting, false);
        return view('admin.post.list')->with(array('type' => $type, 'adminURI' => $this->adminURI, 'pageTitle' => $pageTitle));
    }

    public function create($type = "page") {
        $typeSetting = SettingHelper::getSetting($type);
        if (!$typeSetting) {
            return redirect($this->adminURI . '404');
        } else {
            $post = '';
            $media = '';
            $actionTxt = 'Save';
            $isEdit = FALSE;
            $action = $this->adminURI . 'post/save';
            $pageTitle = SettingHelper::getPageTitleByType($typeSetting);
            $categoryData = $typeSetting['categoryBox']['data'][0];
            $categorys = null;
            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple'] == false) {
                $categorys = $this->getCategoryList(false, "all", $categoryData);
            }
            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple']) {
                $categorys = Category::with(['parents', 'childs'])->where('type', $categoryData)->where('status', 'publish')->get(['id', 'parent_id', 'title']);
            }
            $brands = $this->getBrandList();
            $attributes = $this->getAttributeList(true);
            $cAttributes = Attribute::with('values')->where('status', '=', 'publish')->get();
            $postListing = $this->getPost($type, true);


            return view('admin.post.add-edit')->with(array(
                        'type' => $type,
                        'categorys' => $categorys,
                        'brands' => $brands,
                        'adminURI' => $this->adminURI,
                        'post' => $post,
                        'actionTxt' => $actionTxt,
                        'isEdit' => $isEdit,
                        'action' => $action,
                        'pageTitle' => $pageTitle,
                        'attributes' => $attributes,
                        'typeSetting' => $typeSetting,
                        'cAttributes' => $cAttributes,
                        'postListing' => $postListing
            ));
        }
    }

    public function store(Request $request) {

        $type = $request->type;
        $redirectUrl = $this->adminURI . 'post/new/' . $type;
        $typeSetting = SettingHelper::getSetting($type);
        if (!$typeSetting) {
            return redirect($this->adminURI . '404');
        } else {
            $allowType = (isset($typeSetting['featuredImgBox']['extensionAllow'])) ? $typeSetting['featuredImgBox']['extensionAllow'] : 'jpg,jpeg,png,gif';
            $allowTypeStr = StringHelper::arrayToStr($allowType, ',');
            $isImage = (isset($typeSetting['featuredImgBox']['isImg']) && $typeSetting['featuredImgBox']['isImg']) ? true : false;

            $allowType_urdu = (isset($typeSetting['featuredImgBox_urdu']['extensionAllow'])) ? $typeSetting['featuredImgBox_urdu']['extensionAllow'] : 'jpg,jpeg,png,gif';
            $allowTypeStr_urdu = StringHelper::arrayToStr($allowType_urdu, ',');
            $isImage_urdu = (isset($typeSetting['featuredImgBox_urdu']['isImg']) && $typeSetting['featuredImgBox_urdu']['isImg']) ? true : false;

            $validator = Validator::make($request->all(), ['title' => 'required|max:255', 'image' => 'mimes:' . $allowTypeStr], ['mimes' => 'File type should be ' . $allowTypeStr], ['title' => 'required|max:255', 'image' => 'mimes:' . $allowTypeStr_urdu], ['mimes' => 'File type should be ' . $allowTypeStr_urdu]
            );
            if ($validator->fails()) {
                return redirect($redirectUrl)->withErrors($validator)->withInput();
            }
            $pageTitle = SettingHelper::getPageTitleByType($typeSetting);
            $mediaID = Null;
            $slug = StringHelper::Slug(($request->slug == '') ? $request->title : $request->slug, $type, new Post);
            if ($request->hasFile('image')) {
                if ($request->file('image')->isValid()) {
                    $file = $request->file('image');
                    $destinationPath = $this->ImageUploadDir;
                    $fileNewName = str_random(50) . time() . str_random(50);
                    $fileName = $fileNewName . '.' . $file->getClientOriginalExtension();
                    $file->move($destinationPath, $fileName);
                    $media = new Media();
                    $media->image_path = $fileName;
                    $media->save();
                    $mediaID = $media->id;
                    if ($isImage) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                } else {
                    Session::flash('Error', $request->file('image')->getErrorMessage());
                    return redirect($redirectUrl)->withInput();
                }
            }
            $mediaID2 = Null;
            if ($request->hasFile('image2')) {
                if ($request->file('image2')->isValid()) {
                    $file = $request->file('image2');
                    $destinationPath = $this->ImageUploadDir;
                    $fileNewName = str_random(50) . time() . str_random(50);
                    $fileName = $fileNewName . '.' . $file->getClientOriginalExtension();
                    $file->move($destinationPath, $fileName);
                    $media = new Media();
                    $media->image_path = $fileName;
                    $media->save();
                    $mediaID2 = $media->id;
                    if ($isImage_urdu) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                } else {
                    Session::flash('Error', $request->file('image2')->getErrorMessage());
                    return redirect($redirectUrl)->withInput();
                }
            }
            $dbSortOrder = 0;
            $getSortOrder = $request->sort_order;
            if (!$getSortOrder) {
                $dbSortOrder = Post::where('type', $type)->orderBy('sort_order', 'DESC')->first()->sort_order + 1;
            }


            $currentUser = Auth::user();
            $currentUser = $currentUser->id;
            $model = new Post();
            $model->parent_id = $request->parent;
            $model->user_id = $currentUser;
            $model->media_id = $mediaID;
            $model->urdu_media_id = $mediaID2;
            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple'] == false) {
                $model->category_id = ($request->category) ? $request->category : NULL;
            }
            $model->brand_id = ($request->brand) ? $request->brand : NULL;
            $model->sort_order = $dbSortOrder;
            $model->title = $request->title;
            $model->title_urdu = $request->title_urdu;
            $model->slug = $slug;
            $model->sku_code = $request->sku_code;
            $model->url = $request->url;
            $model->short_discription = e($request->short_discription);
            $model->full_discription = e($request->full_discription);
            $model->short_discription_urdu = e($request->short_discription_urdu);
            $model->full_discription_urdu = e($request->full_discription_urdu);
            $model->cash_price = $request->cash_price;
            $model->sale_price = $request->sale_price;
            $model->down_price = $request->down_price;
            $model->min_term = $request->min_term;
            $model->max_term = $request->max_term;
            $model->installment_amount = $request->installment_amount;
            $model->is_available = $request->is_available;
            $model->is_featured = $request->is_featured;
            $model->is_best_seller = $request->is_best_seller;
            $model->is_new = $request->is_new;
            $model->max_term = $request->max_term;
            $model->is_sale = $request->is_sale;
            $model->is_mostly_viwed = $request->is_mostly_viwed;
            $model->is_deal = $request->is_deal;
            $model->type = $type;
            $model->status = $request->status;
            $model->save();
            $cAttributes = Attribute::with('values')->where('status', '=', 'publish')->get();
            if ($cAttributes->count() > 0) {
                foreach ($cAttributes as $attributeVal) {
                    $valName = $attributeVal->code . '-' . $attributeVal->id;
                    if ($request->{$valName} != '') {
                        $subModel = new PostAttribute();
                        $subModel->post_id = $model->id;
                        $subModel->attribute_id = $attributeVal->id;
                        $subModel->value = $request->{$valName};
                        $subModel->save();
                    }
                }
            }

            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple']) {
//mulliple select code here
                $multicategory = $request->multicategory;
                if (is_array($multicategory) && !empty($multicategory)) {
                    foreach ($multicategory as $cat) {
                        $categoryPost = new \App\Models\CategoryPost();
                        $categoryPost->post_id = $model->id;
                        $categoryPost->category_id = $cat;
                        $categoryPost->user_id = $currentUser;
                        $categoryPost->save();
                    }
                }
            }

            if ($model) {
                $this->sendNotification($type, $model, $request->multicategory); //RSS Notifcaiton Send
                Session::flash('Success', $pageTitle . ' successfully saved.');
                return redirect($redirectUrl);
            } else {
                Session::flash('Error', $pageTitle . ' has not been saved.');
                return redirect($redirectUrl)->withInput();
            }
        }
    }

    public function edit($type = "page", $id) {
        $typeSetting = SettingHelper::getSetting($type);
        if (!$typeSetting) {
            return redirect($this->adminURI . '404');
        } else {
            $actionTxt = 'Update';
            $isEdit = TRUE;
            $action = $this->adminURI . 'post/update';
            $pageTitle = SettingHelper::getPageTitleByType($typeSetting);
            $post = Post::with('media')->where('status', '!=', 'trash')->where('id', '=', $id)->where('type', '=', $type)->first();
            $categoryData = $typeSetting['categoryBox']['data'][0];
            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple'] == false) {
                $categorys = $this->getCategoryList(false, "all", $categoryData);
            }
            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple']) {
                $categorys = Category::with(['parents', 'childs'])->where('type', $categoryData)->where('status', 'publish')->where('parent_id', 0)->get(['id', 'parent_id', 'title']);
            }
            $brands = $this->getBrandList();
            $attributes = $this->getAttributeList(true);
            $cAttributes = Attribute::with('values')->where('status', '=', 'publish')->get();
            $postListing = $this->getPost($type, true);



            return view('admin.post.add-edit')->with(array(
                        'type' => $type,
                        'categorys' => (isset($categorys)) ? $categorys : null,
                        'brands' => $brands,
                        'adminURI' => $this->adminURI,
                        'actionTxt' => $actionTxt,
                        'isEdit' => $isEdit,
                        'post' => $post,
                        'action' => $action,
                        'pageTitle' => $pageTitle,
                        'attributes' => $attributes,
                        'typeSetting' => $typeSetting,
                        'cAttributes' => $cAttributes,
                        'postListing' => $postListing
            ));
        }
    }

    public function update(Request $request) {
        $type = $request->type;
        $id = $request->old_id;
        $redirectUrl = $this->adminURI . 'post/edit/' . $type . '/' . $id;
        $typeSetting = SettingHelper::getSetting($type);
        $pageTitle = SettingHelper::getPageTitleByType($typeSetting);
        if (!$typeSetting) {
            return redirect($this->adminURI . '404');
        } else {
            $allowType = (isset($typeSetting['featuredImgBox']['extensionAllow'])) ? $typeSetting['featuredImgBox']['extensionAllow'] : 'jpg,jpeg,png,gif';
            $allowTypeStr = StringHelper::arrayToStr($allowType, ',');
            $isImage = (isset($typeSetting['featuredImgBox']['isImg']) && $typeSetting['featuredImgBox']['isImg']) ? true : false;

            $allowType_urdu = (isset($typeSetting['featuredImgBox_urdu']['extensionAllow'])) ? $typeSetting['featuredImgBox_urdu']['extensionAllow'] : 'jpg,jpeg,png,gif';
            $allowTypeStr_urdu = StringHelper::arrayToStr($allowType_urdu, ',');
            $isImage_urdu = (isset($typeSetting['featuredImgBox_urdu']['isImg']) && $typeSetting['featuredImgBox_urdu']['isImg']) ? true : false;

            $validator = Validator::make($request->all(), ['title' => 'required|max:255', 'image' => 'mimes:' . $allowTypeStr], ['mimes' => 'File type should be ' . $allowTypeStr], ['title' => 'required|max:255', 'image' => 'mimes:' . $allowTypeStr_urdu], ['mimes' => 'File type should be ' . $allowTypeStr_urdu]
            );
            if ($validator->fails()) {
                return redirect($redirectUrl)->withErrors($validator)->withInput();
            }
            $title = $request->title;
            if ($id) {
                $oldMediaId = $oldImagepath = "";
                $model = Post::with('media')->where('status', '!=', 'trash')->where('id', '=', $id)->where('type', '=', $type)->first();
                if ($model->title != $title) {
                    $slug = StringHelper::Slug(($request->slug == $model->slug) ? $title : $request->slug, $type, new Post);
                } else {
                    $slug = $model->slug;
                }
            } else {
                Session::flash('Error', 'Invalid Request');
                return redirect($redirectUrl);
            }
            $mediaID = $model->media_id;
            if ($request->hasFile('image')) {
                if ($request->file('image')->isValid()) {
                    if ($model->media_id != NULL || $model->media_id != '') {
                        $oldMediaId = $model->media_id;
                        $oldImagepath = $model->media->image_path;
                    }
                    $file = $request->file('image');
                    $destinationPath = $this->ImageUploadDir;
                    $fileNewName = str_random(50) . time() . str_random(50);
                    $fileName = $fileNewName . '.' . $file->getClientOriginalExtension();
                    $file->move($destinationPath, $fileName);
                    $media = new Media();
                    $media->image_path = $fileName;
                    $media->save();
                    $mediaID = $media->id;
                    if ($isImage) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                    if ($isImage_urdu) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                } else {
                    Session::flash('Error', $request->file('image')->getErrorMessage());
                    return redirect($redirectUrl)->withInput();
                }
            }
            $mediaID2 = $model->urdu_media_id;
            if ($request->hasFile('image2')) {
                if ($request->file('image2')->isValid()) {
                    if ($model->media_id != NULL || $model->media_id != '') {
                        $oldMediaId = $model->media_id;
                        $oldImagepath = $model->media->image_path;
                    }
                    $file = $request->file('image2');
                    $destinationPath = $this->ImageUploadDir;
                    $fileNewName = str_random(50) . time() . str_random(50);
                    $fileName = $fileNewName . '.' . $file->getClientOriginalExtension();
                    $file->move($destinationPath, $fileName);
                    $media = new Media();
                    $media->image_path = $fileName;
                    $media->save();
                    $mediaID2 = $media->id;
                    if ($isImage) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                    if ($isImage_urdu) {
                        MediaHelper::createThumb($fileNewName, $file->getClientOriginalExtension(), $type);
                    }
                } else {
                    Session::flash('Error', $request->file('image2')->getErrorMessage());
                    return redirect($redirectUrl)->withInput();
                }
            }
            $currentUser = Auth::user();
            $currentUser = $currentUser->id;
            $model->parent_id = $request->parent;
            $model->user_id = $currentUser;
            $model->media_id = $mediaID;

            $getSortOrder = $request->sort_order;



            if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple'] == false) {
                $model->category_id = ($request->category == 0) ? NULL : $request->category;
            }
            $model->brand_id = ($request->brand == 0) ? NULL : $request->brand;
            if ($getSortOrder) {
                $model->sort_order = $request->sort_order;
            }
            $model->title = $request->title;
            $model->title_urdu = $request->title_urdu;
            $model->slug = $slug;
            $model->sku_code = $request->sku_code;
            $model->url = $request->url;
            $model->short_discription = e($request->short_discription);
            $model->full_discription = e($request->full_discription);
            $model->short_discription_urdu = e($request->short_discription_urdu);
            $model->full_discription_urdu = e($request->full_discription_urdu);
            $model->cash_price = $request->cash_price;
            $model->sale_price = $request->sale_price;
            $model->down_price = $request->down_price;
            $model->min_term = $request->min_term;
            $model->max_term = $request->max_term;
            $model->installment_amount = $request->installment_amount;
            $model->is_available = $request->is_available;
            $model->is_featured = $request->is_featured;
            $model->is_best_seller = $request->is_best_seller;
            $model->is_new = $request->is_new;
            $model->max_term = $request->max_term;
            $model->is_sale = $request->is_sale;
            $model->is_mostly_viwed = $request->is_mostly_viwed;
            $model->is_deal = $request->is_deal;
            $model->type = $type;
            $model->status = $request->status;

            $model->update();
            if ($model) {
                $cAttributes = Attribute::with('values')->where('status', '=', 'publish')->get();
                if ($cAttributes->count() > 0) {
                    $postAttributes = PostAttribute::where('post_id', '=', $model->id)->delete();
                    foreach ($cAttributes as $attributeVal) {
                        $valName = $attributeVal->code . '-' . $attributeVal->id;
                        if ($request->{$valName} != '') {
                            $subModel = new PostAttribute();
                            $subModel->post_id = $model->id;
                            $subModel->attribute_id = $attributeVal->id;
                            $subModel->value = $request->{$valName};
                            $subModel->save();
                        }
                    }
                }
                if ($typeSetting['categoryBox']['isView'] && $typeSetting['categoryBox']['isMultiple']) {
//$SelectedCategories = $model->postCategoreis()->delete();
                    $SelectedCategories = $model->postCategoreis()->get();
//mulliple select code here


                    $multicategory = $request->multicategory;

                    if (is_array($multicategory) && !empty($multicategory)) {
                        if (count($SelectedCategories) > 0) {
                            foreach ($SelectedCategories as $scategory) {
                                if (!in_array($scategory->category_id, $multicategory)) {
                                    $scategory->delete();
                                }
                            }
                        }
                        foreach ($multicategory as $cat) {

                            $catPost = \App\Models\CategoryPost::where([
                                        'category_id' => $cat,
                                        'post_id' => $model->id,
                                    ])->first();
                            if (count($catPost) == 0) {
                                $categoryPost = new \App\Models\CategoryPost();
                                $categoryPost->post_id = $model->id;
                                $categoryPost->category_id = $cat;
                                $categoryPost->user_id = $currentUser;
                                $categoryPost->save();
                            }
                        }
                    } else {
                        $model->postCategoreis()->delete();
                    }
                }

                if ($oldMediaId != '' || $oldMediaId != NULL) {
                    $oldFile = Media::find($oldMediaId)->delete();
                    MediaHelper::physicalMediaDelete($oldImagepath, $type);
                }
                Session::flash('Success', $pageTitle . ' successfully update.');
                return redirect($redirectUrl);
            } else {
                Session::flash('Error', $pageTitle . ' has not been update.');
                return redirect($redirectUrl)->withInput();
            }
        }
    }

    public function delete(Request $request, $type = "page", $id) {
        $redirectUrl = $this->adminURI . 'post/list/' . $type;
        $model = Post::where('id', $id)->delete();
        if ($model) {
            Session::flash('Success', $type . ' has been deleted successfully...');
        } else {
            Session::flash('Error', $type . ' has not been deleted.');
        }

        return redirect($redirectUrl);
    }

    public function addAttributePost(Request $request) {
        if (!$request->ajax()) {
            $response = array('Good' => false, 'Message' => 'Invalid Request');
            return \Response::json($response);
        }

        $validator = Validator::make($request->all(), ['key' => 'required|numeric', 'val' => 'required|max:255']);
        if ($validator->fails()) {
            $response = array('Good' => false, 'Message' => $validator->errors()->all());
            return \Response::json($response);
        }
        $model = new PostAttribute();
        $model->post_id = $request->post_id;
        $model->attribute_id = $request->key;
        $model->value = $request->val;
        $model->save();
        if ($model) {
            $response = array('Good' => true, 'Message' => 'Attribute add successfully...');
        } else {
            $response = array('Good' => false, 'Message' => 'Attribute not added');
        }
        return \Response::json($response);
    }

    public function addedAttributeList(Request $request, $id) {

        if (!$request->ajax()) {
            $response = array('Good' => false, 'Message' => 'Invalid Request');
            return \Response::json($response);
        }
        $model = Post::with('attribute')->where('status', '!=', 'trash')->where('id', '=', $id)->first();
        return view('admin.post.post-attribute-list-item')->with(array(
                    'items' => $model->attribute
        ));
    }

    public function deleteAttributeItem(Request $request, $postId, $attributeId) {
        if (!$request->ajax()) {
            $response = array('Good' => false, 'Message' => 'Invalid Request');
            return \Response::json($response);
        }
        $model = PostAttribute::where('attribute_id', '=', $attributeId)->where('post_id', '=', $postId)->delete();
        if ($model) {
            $response = array('Good' => true, 'Message' => 'Attribute remove successfully...');
        } else {
            $response = array('Good' => false, 'Message' => 'Attribute not remove');
        }
        return \Response::json($response);
    }

    private function sendNotification($type, $post, $categories=[]) {
        $subcribes = \App\Models\Subscription::where('status', 'publish')->get();
        $sent = '';

        $page = null;
        if (!empty($categories)) {
            $cates = Category::with(['posts' => function($query) {
                            $query->where(['status' => 'publish', 'type' => 'page']);
                        }])->where(['status' => 'publish'])->whereIn('id', $categories)->get();

            if ($cates) {
                foreach ($cates as $cate) {
                    if ($cate && $cate->posts->count() > 0) {
                        $page = $cate->posts[0];
                        break;
                    }
                }
            }
        }
        foreach ($subcribes as $subcribe) {
            $isSendNotification = $this->getModuleName($type, $subcribe->getNotifictionOn(true));
            if ($isSendNotification) {

                $data = array(
                    'to' => $subcribe->email,
                    'subject' => 'OGRA\'s Website Update',
                    'template' => 'rss',
                    'message' => '',
                    'data' => ['post' => $post, 'page' => $page],
                    'name' => $subcribe->getFullName(),
                    'attachments' => array(),
                );

                $sent = StringHelper::sendMail($data);
            }
        }
        return $sent;
    }

    private function getModuleName($type, $modules) {
        $systemModules = StringHelper::getModuleForRSS();
        if (is_array($modules)) {
            foreach ($modules as $module) {
                if (array_key_exists($module, $systemModules)) {
                    if (isset($systemModules[$module]) && $systemModules[$module] != '' && $type == $systemModules[$module]) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    public function getData(Request $request, $type) {

        $columns = array('id', 'title', 'status', 'id');


        $totalData = Post::where(['type' => $type])->count();
        $totalFiltered = $totalData;

        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');

        if (empty($request->input('search.value'))) {
            $posts = Post::where(['type' => $type])->offset($start)
                    ->limit($limit)
                    ->orderBy($order, $dir)
                    ->get(array('id', 'sku_code', 'title', 'status', 'id'));
        } else {
            $search = $request->input('search.value');
            $posts = Post::where(['type' => $type])->where(function($query) use($type, $search) {
                        //$query->where('type', $type);
                        $query->orWhere('id', 'LIKE', "%{$search}%");
                        $query->orWhere('title', 'LIKE', "%{$search}%");
                        $query->orWhere('sku_code', 'LIKE', "%{$search}%");
                        $query->orWhere('status', 'LIKE', "%{$search}%");
                    })
                    ->offset($start)
                    ->limit($limit)
                    ->orderBy($order, $dir)
                    ->get($columns);

            $totalFiltered = Post::where(['type' => $type])->where(function($query) use($type, $search) {
                        //$query->where('type', $type);
                        $query->orWhere('id', 'LIKE', "%{$search}%");
                        $query->orWhere('title', 'LIKE', "%{$search}%");
                        $query->orWhere('sku_code', 'LIKE', "%{$search}%");
                        $query->orWhere('status', 'LIKE', "%{$search}%");
                    })
                    ->count();
        }

        $data = array();
        if (!empty($posts)) {
            foreach ($posts as $key => $post) {
                $nestedData['id'] = $post->id;
                $nestedData['title'] = $post->title;
                $nestedData['parent'] = ($post->parents) ? $post->parents->getTitle() : 'None';
                $nestedData['category'] = ($post->category()->first()) ? $post->category()->first()->title : 'None';
                $nestedData['status'] = $post->status;
                $data[] = $nestedData;
            }
        }

        $json_data = array(
            "draw" => intval($request->input('draw')),
            "recordsTotal" => intval($totalData),
            "recordsFiltered" => intval($totalFiltered),
            "data" => $data
        );
        echo json_encode($json_data);
    }

}
