<?php

namespace App\Http\Controllers\Front;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;
use App\Models\Website;
use App\Repositories\WebsiteRepository;
use App\Http\Requests\WebsiteRequest;
use App\Helpers\SlugHelper;

class WebsiteController extends Controller {

    private $viewDir;
    private $model;
    private $request;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct() {
        $this->viewDir = 'front.websites.';
    }

    public function create() {
        return view($this->viewDir . 'create');
    }

    public function store(WebsiteRequest $request) {
        $model = new WebsiteRepository();
        $saved = $model->save($this->setData($request));
        if ($saved) {
            Session::flash('success', 'Website created successfully!');
            return redirect()->route('websites.preview', $saved->slug);
        }
        Session::flash('error', 'Website not created!');
        return redirect()->route('websites.create')->withInput($request->all());
    }

    public function preview($slug) {
        $model = new WebsiteRepository();
        $website = $model->getBySlug($slug);
        return view($this->viewDir . 'preview',compact('website'));
    }

    private function setData($request, $isNew = true) {
        $slug = new SlugHelper(new Website(), $request->input('name'));
        return [
            'name' => $request->input('name'),
            'slug' => $slug->getSlug(),
            'domain' => $request->input('domain'),
            'company_name' => $request->input('company_name'),
            'email' => $request->input('email'),
            'phone' => $request->input('phone'),
            'mobile' => $request->input('mobile'),
            'address_line_1' => $request->input('address_line_1'),
            'address_line_2' => $request->input('address_line_2'),
            'city' => $request->input('city'),
            //'state' => $request->input('state'),
            'country' => $request->input('country'),
        ];
    }
}
