<?php

namespace App\Models;

use Intervention\Image\Facades\Image;

use Illuminate\Database\Eloquent\Model as BaseModel;

class Model extends BaseModel {

    const SOFT_DELETES = false;

    const BASE_UPLOAD_DIR = 'uploads/';
    const PAGINATE_COUNT = 5;

    protected function attachedRelation($request, $relation) {
        return $this->{$relation}()->attach($request->input($relation));
    }

    protected function syncRelation($request, $relation) {
        return $this->{$relation}()->sync($request->input($relation));
    }

    protected function detachRelation() {
        return $this->{$relation}()->detach($request->input($relation));
    }

    public function pluckImplodeAttribute($model, $attribute = 'name', $glue = ', ') {
        return ($model && $model->count() > 0) ? $model->pluck($attribute)->implode($glue) : null;
    }

    public function getCount($model) {
        return $model->count();
    }

    public function getCreatedAt() {
        return $this->created_at->format('d/m/y');
    }

    public function imploadArray($arr) {
        return (is_array($arr) && !empty($arr)) ? implode(',', $arr) : '';
    }

    public function generateThumbnail($filename, $media_dir, $width = 350, $height = 350, $id) {
        $full_dir = $media_dir . '/' . $filename;
        $extension_pos = strrpos($filename, '.'); // find position of the last dot, so where the extension starts
        $thumb = substr($filename, 0, $extension_pos) . '_thumb' . substr($filename, $extension_pos);
        $path = public_path($media_dir . '/' . $thumb);
        // $path = public_path(self::BASE_UPLOAD_DIR . self::WEDDINGLIST_UPLOAD_DIR .$id.'/' . $thumb);
        Image::make($full_dir)->resize($width, $height)->save($path);
        $thumbnail = $full_dir . '/' . $thumb;
        return $thumbnail;
    }
    
    public function thumbNameConverter($filename, $thumb_width, $thumb_height) {
        $extension_pos = strrpos($filename, '.'); // find position of the last dot, so where the extension starts
        $thumb = substr($filename, 0, $extension_pos) . '_thumb_' . $thumb_width . 'x' . $thumb_height . substr($filename, $extension_pos);
        return asset($thumb);
    }

}
